@@ -336,24 +336,57 @@ def linearregression_builtin():
 def webCrawl():
     #  Program to implement a simple web crawler using python
 
-    txt = "import requests"\
-        "from bs4 import BeautifulSoup"\
-        "url = 'https://www.geeksforgeeks.org'"\
-        "r = requests.get(url)"\
-        "soup = BeautifulSoup(r.text, 'html.parser')"\
-        "print(soup.prettify())"\
-        "for row in soup.find_all('a'):"\
-            "data = row.get['href']"\
-            "f = open('abc.py', 'a')"\
-            "print(data)"\
-            "f.write(data)"\
-            "f.write('\n')"\
+    txt = "import requests\n"\
+        "from bs4 import BeautifulSoup\n"\
+        "url = 'https://www.geeksforgeeks.org'\n"\
+        "r = requests.get(url)\n"\
+        "soup = BeautifulSoup(r.text, 'html.parser')\n"\
+        "print(soup.prettify())\n"\
+        "for row in soup.find_all('a'):\n"\
+            "data = row.get['href']\n"\
+            "f = open('abc.py', 'a')\n"\
+            "print(data)\n"\
+            "f.write(data)\n"\
+            "f.write('\n')\n"\
             "f.close()"
     f = open("res.py", "w")
     f.write(txt)
     f.close()
     return txt
-
+    
+def mulRegression():
+    txt = "import matplotlib.pyplot as plt\n"\
+        "from sklearn import datasets, linear_model\n"\
+        "from sklearn.metrics import mean_squared_error, r2_score\n"\
+        "boston = datasets.load_boston(return_X_y=False)\n"\
+        "X = boston.data\n"\
+        "y = boston.target\n"\
+        "from sklearn.model_selection import train_test_split\n"\
+        "X_train, X_test, y_train, y_test = train_test_split(X, y, test_size=0.3, random_state=1)\n"\
+        "reg = linear_model.LinearRegression()\n"\
+        "reg.fit(X_train, y_train)\n"\
+        "predicted = reg.predict(X_test)\n"\
+        "# Regression coefficient\n"\
+        "print('Coefficients are:\n', reg.coef_)\n"\
+        "# Intecept\n"\
+        "print('\nIntercept : ', reg.intercept_)\n"\
+        "# variance score: 1 means perfect prediction\n"\
+        "print('Variance score: ', reg.score(X_test, y_test))\n"\
+        "# Mean Squared Error\n"\
+        "print('Mean squared error: %.2f' % mean_squared_error(y_test, predicted))\n"\
+        "# Original data of X_test\n"\
+        "expected = y_test\n"\
+        "# Plot a graph for expected and predicted values\n"\
+        "plt.title('ActualPrice Vs PredictedPrice (BOSTON Housing Dataset)')\n"\
+        "plt.scatter(expected, predicted, c='b', marker='.', s=36)\n"\
+        "plt.plot([0, 50], [0, 50], '--r')\n"\
+        "plt.xlabel('Actual Price(1000$)')\n"\
+        "plt.ylabel('Predicted Price(1000$)')\n"\
+        "plt.show()"
+    f = open("res.py", "w")
+    f.write(txt)
+    f.close()
+    return txt
 
 def info():
     # Use it for educational purpose only
